open_fixations_file: Retusns fixations data.frame

Description Usage Arguments Value

View source: R/pupilr-loading.R

Description

returns loaded fixations file from the folder, in case you exported it as part of the export

Usage

1

Arguments

folder

directory with the exported data

Value

data.frame with loaded fixations positions


hejtmy/pupilr documentation built on April 23, 2021, 11:53 a.m.