Description Usage Arguments Value
View source: R/pupilr-loading.R
returns loaded fixations file from the folder, in case you exported it as part of the export
1 | open_fixations_file(folder)
|
folder |
directory with the exported data |
data.frame with loaded fixations positions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.